.. currentmodule:: abjad.tools.scoretools

apply_full_measure_tuplets_to_contents_of_measures_in_expr
==========================================================

.. autofunction:: apply_full_measure_tuplets_to_contents_of_measures_in_expr
